@@ -113,7 +113,7 @@ void Kwave::BandPass::input(Kwave::SampleArray data)
 
     bool ok = m_buffer.resize(in.size());
     Q_ASSERT(ok);
-    Q_UNUSED(ok);
+    Q_UNUSED(ok)
 
     setfilter_2polebp(m_frequency, m_bandwidth);
 
@@ -121,19 +121,19 @@ void Kwave::BandPass::input(Kwave::SampleArray data)
 
     for (unsigned i = 0; i < in.size(); ++i)
     {
-	// do the filtering
-	m_filter.x = sample2double(in[i]);
-	m_filter.y =
-	    m_filter.cx  * m_filter.x  +
-	    m_filter.cx1 * m_filter.x1 +
-	    m_filter.cx2 * m_filter.x2 +
-	    m_filter.cy1 * m_filter.y1 +
-	    m_filter.cy2 * m_filter.y2;
-	m_filter.x2 = m_filter.x1;
-	m_filter.x1 = m_filter.x;
-	m_filter.y2 = m_filter.y1;
-	m_filter.y1 = m_filter.y;
-	m_buffer[i] = double2sample(0.95 * m_filter.y);
+        // do the filtering
+        m_filter.x = sample2double(in[i]);
+        m_filter.y =
+            m_filter.cx  * m_filter.x  +
+            m_filter.cx1 * m_filter.x1 +
+            m_filter.cx2 * m_filter.x2 +
+            m_filter.cy1 * m_filter.y1 +
+            m_filter.cy2 * m_filter.y2;
+        m_filter.x2 = m_filter.x1;
+        m_filter.x1 = m_filter.x;
+        m_filter.y2 = m_filter.y1;
+        m_filter.y1 = m_filter.y;
+        m_buffer[i] = double2sample(0.95 * m_filter.y);
     }
 }
 
